Class: Composable::Pwdless::Form::Authentication
- Inherits:
-
Form::Command
- Object
- Form::Command
- Composable::Pwdless::Form::Authentication
- Defined in:
- app/services/composable/pwdless/form/authentication.rb
Instance Method Summary collapse
Instance Method Details
#save ⇒ Object
11 12 13 14 15 |
# File 'app/services/composable/pwdless/form/authentication.rb', line 11 def save # We don't want the code in the verification, otherwise the user will # set it on the subsequent request, which would undermine the whole thing. Form::Verification.new(salt: salt, data: email) end |